@@ -1,17 +1,22 @@
 #' Anonymise factor levels
 #'
-#' Replaces factor levels with arbitary numeric identifiers. Neither
+#' Replaces factor levels with arbitrary numeric identifiers. Neither
 #' the values nor the order of the levels are preserved.
 #'
-#' @param f A factor
+#' @param f A factor.
 #' @param prefix A character prefix to insert in front of the random labels.
 #' @export
 #' @examples
-#' gss_cat$relig %>% fct_count()
-#' gss_cat$relig %>% fct_anon() %>% fct_count()
-#' gss_cat$relig %>% fct_anon() %>% fct_count()
-#' gss_cat$relig %>% fct_anon("X") %>% fct_count()
+#' gss_cat$relig |> fct_count()
+#' gss_cat$relig |>
+#'   fct_anon() |>
+#'   fct_count()
+#' gss_cat$relig |>
+#'   fct_anon("X") |>
+#'   fct_count()
 fct_anon <- function(f, prefix = "") {
+  f <- check_factor(f)
+  check_string(prefix)
   levels <- paste0(prefix, zero_pad(seq_len(nlevels(f))))
 
   f <- lvls_revalue(f, sample(levels))
